@@ -6,4 +6,4 @@ Created on Sat Oct 12 12:43:59 2019
 """
 
 
-from . pyANA import pyANA
+from . pyANA import ANA
